#!/usr/bin/python3
import subprocess
import sys
import time

import gi
from gi.repository import Gio, GLib, GObject

UDI = "/org/freedesktop/UDisks2/block_devices/sdb"
ESP_GUID = 'C12A7328-F81F-11D2-BA4B-00A0C93EC93B'

bus = Gio.bus_get_sync(Gio.BusType.SYSTEM, None)
print("Getting Block proxy")
block_proxy = Gio.DBusProxy.new_sync(bus,
            Gio.DBusProxyFlags.NONE,
            None,
            "org.freedesktop.UDisks2",
            "/org/freedesktop/UDisks2/block_devices/sdb",
            "org.freedesktop.UDisks2.Block",
            None)
print("Calling Format")
block_proxy.call_sync("Format",
            GLib.Variant.new_tuple(GLib.Variant.new_string('gpt'),
                                   GLib.Variant('a{sv}', None)),
            Gio.DBusCallFlags.NONE,
            GObject.G_MAXINT,
            None)
print("Getting PartitionTable proxy")
pt_proxy = Gio.DBusProxy.new_sync(bus,
            Gio.DBusProxyFlags.NONE,
            None,
            "org.freedesktop.UDisks2",
            "/org/freedesktop/UDisks2/block_devices/sdb",
            "org.freedesktop.UDisks2.PartitionTable",
            None)
print("Calling CreatePartition")
try:
    pt_proxy.call_sync("CreatePartition",
            GLib.Variant.new_tuple(GLib.Variant.new_uint64(0),
                                   GLib.Variant.new_uint64(2500 * 2**20),
                                   GLib.Variant.new_string(ESP_GUID),
                                   GLib.Variant.new_string("Test"),
                                   GLib.Variant('a{sv}', None)),
            Gio.DBusCallFlags.NONE,
            GObject.G_MAXINT,
            None)
except GLib.Error as e:
    # XXX: as of Debian Jessie, we often get errors while wiping
    # (Debian bug #767457). We ignore them as they are not fatal
    # for us... but we need to fix a few things later...
    if ('GDBus.Error:org.freedesktop.UDisks2.Error.Failed' in e.message and
            'Error wiping newly created partition' in e.message):
        print("Ignoring error %s" % e.message)
    else:
        raise

print("Spawning sync")
subprocess.check_call("sync")

print("Calling Rescan")
block_proxy.call_sync("Rescan",
        GLib.Variant.new_tuple(GLib.Variant('a{sv}', None)),
        Gio.DBusCallFlags.NONE,
        GObject.G_MAXINT,
        None)

print("Getting Partition proxy")
part_proxy = Gio.DBusProxy.new_sync(bus,
        Gio.DBusProxyFlags.NONE,
        None,
        "org.freedesktop.UDisks2",
        "/org/freedesktop/UDisks2/block_devices/sdb1",
        "org.freedesktop.UDisks2.Partition",
        None)

print("Calling SetType")
part_proxy.call_sync("SetType",
        GLib.Variant.new_tuple(
                GLib.Variant.new_string(ESP_GUID),
                GLib.Variant('a{sv}', None)),
        Gio.DBusCallFlags.NONE,
        GObject.G_MAXINT,
        None)

print("Calling SetName")
part_proxy.call_sync("SetName",
        GLib.Variant.new_tuple(
                GLib.Variant.new_string("Test"),
                GLib.Variant('a{sv}', None)),
        Gio.DBusCallFlags.NONE,
        GObject.G_MAXINT,
        None)

print("Done!")
